Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodeStar Notifications.

Actions, resources, and condition keys for AWS CodeStar Notifications - Service Authorization Reference

# Actions, resources, and condition keys for AWS CodeStar Notifications

AWS CodeStar Notifications (service prefix: `codestar-notifications` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS CodeStar Notifications
- Resource types defined by AWS CodeStar Notifications
- Condition keys for AWS CodeStar Notifications

## Actions defined by AWS CodeStar Notifications

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateNotificationRule | Grants permission to create a notification rule for a resource | Write | notificationrule* |  |
| aws:RequestTag/${TagKey} aws:TagKeys codestar-notifications:NotificationsForResource |
DeleteNotificationRule | Grants permission to delete a notification rule for a resource | Write | notificationrule* |  |
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys codestar-notifications:NotificationsForResource |
DeleteTarget | Grants permission to delete a target for a notification rule | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DescribeNotificationRule | Grants permission to get information about a notification rule | Read | notificationrule* |  |
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys codestar-notifications:NotificationsForResource |
ListEventTypes | Grants permission to list notifications event types | List |  |  |
ListNotificationRules | Grants permission to list notification rules in an AWS account | List |  |  |
ListTagsForResource | Grants permission to list the tags attached to a notification rule resource ARN | List | notificationrule* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
ListTargets | Grants permission to list the notification rule targets for an AWS account | List |  | aws:RequestTag/${TagKey} aws:TagKeys |
Subscribe | Grants permission to create an association between a notification rule and an Amazon SNS topic | Write | notificationrule* |  |
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys codestar-notifications:NotificationsForResource |
TagResource | Grants permission to attach resource tags to a notification rule resource ARN | Tagging | notificationrule* |  |
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys |
Unsubscribe | Grants permission to remove an association between a notification rule and an Amazon SNS topic | Write | notificationrule* |  |
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys codestar-notifications:NotificationsForResource |
UntagResource | Grants permission to disassociate resource tags from a notification rule resource ARN | Tagging | notificationrule* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateNotificationRule | Grants permission to change a notification rule for a resource | Write | notificationrule* |  |
| aws:ResourceTag/${TagKey} aws:RequestTag/${TagKey} aws:TagKeys codestar-notifications:NotificationsForResource |

## Resource types defined by AWS CodeStar Notifications

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
notificationrule | `arn:$ { Partition}:codestar-notifications:$ { Region}:$ { Account}:notificationrule/$ { NotificationRuleId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS CodeStar Notifications

AWS CodeStar Notifications defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String
codestar-notifications:NotificationsForResource | Filters access based on the ARN of the resource for which notifications are configured | ARN

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.